Installing
==========

Installing disnake-compass
---------------------------------

To install disnake-compass, you must be using Python version 3.10 or above and disnake version 2.10 or above.

disnake-compass can be installed directly from PyPI.
The exact command used varies depending on your system.

.. tab:: Windows

    .. code-block:: powershell

        > py -m pip install -U disnake-compass

.. tab:: MacOS / Linux

    .. code-block:: sh

        $ python3 -m pip install -U disnake-compass


Installing a development version
--------------------------------

In case you want to contribute to disnake-compass or try the latest in development version,
you can directly install it from github.

.. tab:: Windows

    .. code-block:: powershell

        > py -m pip install -U git+https://github.com/DisnakeCommunity/disnake-compass

.. tab:: MacOS / Linux

    .. code-block:: sh

        $ python3 -m pip install -U git+https://github.com/DisnakeCommunity/disnake-compass
